Queue
=====

In the following animation, :attr:`shuffle_subjects` is ``False``
and :attr:`shuffle_patches` is ``True``.

.. raw:: html

    <embed>
        <iframe style="width: 640px; height: 360px; overflow: hidden;"  scrolling="no" frameborder="0" src="https://editor.p5js.org/embed/DZwjZzkkV"></iframe>
    </embed>


.. currentmodule:: torchio.data

:class:`Queue`
~~~~~~~~~~~~~~

.. autoclass:: Queue
    :members:
    :show-inheritance:
